from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import cdktf._jsii
import cdktf_cdktf_provider_google._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdktf-gitlab-runner",
    "0.0.881",
    __name__[0:-6],
    "cdktf-gitlab-runner@0.0.881.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
